@@ -1,5 +1,6 @@
 import statistics
 
+from django.conf import settings
 from django.contrib import admin
 from django.db import models
 from django.db.models import Count
@@ -15,6 +16,8 @@ from . import __title__, app_settings, tasks
 from .models import (
     FuelAlert,
     FuelAlertConfig,
+    JumpFuelAlert,
+    JumpFuelAlertConfig,
     Notification,
     NotificationType,
     Owner,
@@ -28,9 +31,8 @@ from .models import (
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
 
-@admin.register(FuelAlert)
-class FuelAlertAdmin(admin.ModelAdmin):
-    list_display = ("config", "_owner", "structure", "hours", "created_at")
+class BaseFuelAlertAdmin(admin.ModelAdmin):
+    list_display = ("config", "_owner", "structure")
     list_select_related = (
         "config",
         "structure",
@@ -43,7 +45,7 @@ class FuelAlertAdmin(admin.ModelAdmin):
         ("structure", admin.RelatedOnlyFieldListFilter),
         ("structure__owner", admin.RelatedOnlyFieldListFilter),
     )
-    ordering = ("config", "structure", "-hours")
+    ordering = ("config", "structure")
 
     def _owner(self, obj):
         return obj.structure.owner
@@ -55,13 +57,20 @@ class FuelAlertAdmin(admin.ModelAdmin):
         return False
 
 
-@admin.register(FuelAlertConfig)
-class FuelNotificationConfigAdmin(admin.ModelAdmin):
+if settings.DEBUG:
+
+    @admin.register(FuelAlert)
+    class StructureFuelAlertAdmin(BaseFuelAlertAdmin):
+        list_display = BaseFuelAlertAdmin.list_display + ("hours",)
+        ordering = BaseFuelAlertAdmin.ordering + ("-hours",)
+
+    @admin.register(JumpFuelAlert)
+    class JumpFuelAlertAdmin(BaseFuelAlertAdmin):
+        pass
+
+
+class BaseFuelAlertConfigAdmin(admin.ModelAdmin):
     list_display = (
-        "__str__",
-        "start",
-        "end",
-        "repeat",
         "channel_ping_type",
         "_color",
         "is_enabled",
@@ -72,6 +81,8 @@ class FuelNotificationConfigAdmin(admin.ModelAdmin):
     def _id(self, obj):
         return f"#{obj.pk}"
 
+    _id.admin_order_field = "pk"
+
     def _color(self, obj):
         color = Webhook.Color(obj.color)
         return format_html(
@@ -99,6 +110,24 @@ class FuelNotificationConfigAdmin(admin.ModelAdmin):
         "Sent fuel notifications for selected configuration"
     )
 
+    fieldsets = (
+        (
+            "Discord",
+            {"fields": ("channel_ping_type", "color")},
+        ),
+        ("General", {"fields": ("is_enabled",)}),
+    )
+
+
+@admin.register(FuelAlertConfig)
+class StructureFuelAlertConfigAdmin(BaseFuelAlertConfigAdmin):
+    list_display = (
+        "_id",
+        "start",
+        "end",
+        "repeat",
+    ) + BaseFuelAlertConfigAdmin.list_display
+
     fieldsets = (
         (
             "Timeing",
@@ -112,12 +141,30 @@ class FuelNotificationConfigAdmin(admin.ModelAdmin):
                 "fields": ("start", "end", "repeat"),
             },
         ),
+    ) + BaseFuelAlertConfigAdmin.fieldsets
+
+
+@admin.register(JumpFuelAlertConfig)
+class JumpFuelAlertConfigAdmin(BaseFuelAlertConfigAdmin):
+    list_display = (
+        "_id",
+        "_threshold",
+    ) + BaseFuelAlertConfigAdmin.list_display
+
+    def _threshold(self, obj) -> str:
+        return f"{obj.threshold:,}"
+
+    _threshold.admin_order_field = "threshold"
+
+    fieldsets = (
         (
-            "Discord",
-            {"fields": ("channel_ping_type", "color")},
+            "Fuel levels",
+            {
+                "description": ("tbd."),
+                "fields": ("threshold",),
+            },
         ),
-        ("General", {"fields": ("is_enabled",)}),
-    )
+    ) + BaseFuelAlertConfigAdmin.fieldsets
 
 
 class RenderableNotificationFilter(admin.SimpleListFilter):
